# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ArcadeProviders,
    AuthenticationServiceTypes,
    ConnectorTypes,
    EntityState,
    IntegrationServiceTypes,
    MCPServerTypes,
    OAuthProviders,
)


class GetConnector(BaseModel):
    connector: Optional["GetConnectorConnector"]


class GetConnectorConnector(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetConnectorConnectorOwner"
    state: EntityState
    type: Optional[ConnectorTypes]
    authentication: Optional["GetConnectorConnectorAuthentication"]
    integration: Optional["GetConnectorConnectorIntegration"]


class GetConnectorConnectorOwner(BaseModel):
    id: str


class GetConnectorConnectorAuthentication(BaseModel):
    type: AuthenticationServiceTypes
    microsoft: Optional["GetConnectorConnectorAuthenticationMicrosoft"]
    google: Optional["GetConnectorConnectorAuthenticationGoogle"]
    oauth: Optional["GetConnectorConnectorAuthenticationOauth"]
    arcade: Optional["GetConnectorConnectorAuthenticationArcade"]


class GetConnectorConnectorAuthenticationMicrosoft(BaseModel):
    tenant_id: str = Field(alias="tenantId")
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class GetConnectorConnectorAuthenticationGoogle(BaseModel):
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class GetConnectorConnectorAuthenticationOauth(BaseModel):
    provider: OAuthProviders
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")
    refresh_token: str = Field(alias="refreshToken")
    metadata: Optional[str]


class GetConnectorConnectorAuthenticationArcade(BaseModel):
    authorization_id: str = Field(alias="authorizationId")
    provider: ArcadeProviders
    metadata: Optional[str]


class GetConnectorConnectorIntegration(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["GetConnectorConnectorIntegrationSlack"]
    email: Optional["GetConnectorConnectorIntegrationEmail"]
    twitter: Optional["GetConnectorConnectorIntegrationTwitter"]
    mcp: Optional["GetConnectorConnectorIntegrationMcp"]


class GetConnectorConnectorIntegrationSlack(BaseModel):
    token: str
    channel: str


class GetConnectorConnectorIntegrationEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class GetConnectorConnectorIntegrationTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


class GetConnectorConnectorIntegrationMcp(BaseModel):
    token: Optional[str]
    type: MCPServerTypes


GetConnector.model_rebuild()
GetConnectorConnector.model_rebuild()
GetConnectorConnectorAuthentication.model_rebuild()
GetConnectorConnectorIntegration.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class GetPerson(BaseModel):
    person: Optional["GetPersonPerson"]


class GetPersonPerson(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetPersonPersonOwner"
    state: EntityState
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[List[Optional["GetPersonPersonFeeds"]]]
    links: Optional[List[Optional["GetPersonPersonLinks"]]]
    workflow: Optional["GetPersonPersonWorkflow"]
    location: Optional["GetPersonPersonLocation"]
    h_3: Optional["GetPersonPersonH3"] = Field(alias="h3")
    address: Optional["GetPersonPersonAddress"]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")
    phone_number: Optional[str] = Field(alias="phoneNumber")
    birth_date: Optional[Any] = Field(alias="birthDate")
    title: Optional[str]
    occupation: Optional[str]
    education: Optional[str]
    works_for: Optional[List[Optional["GetPersonPersonWorksFor"]]] = Field(
        alias="worksFor"
    )
    affiliation: Optional[List[Optional["GetPersonPersonAffiliation"]]]
    member_of: Optional[List[Optional["GetPersonPersonMemberOf"]]] = Field(
        alias="memberOf"
    )
    alumni_of: Optional[List[Optional["GetPersonPersonAlumniOf"]]] = Field(
        alias="alumniOf"
    )
    birth_place: Optional["GetPersonPersonBirthPlace"] = Field(alias="birthPlace")
    death_place: Optional["GetPersonPersonDeathPlace"] = Field(alias="deathPlace")
    home_location: Optional[List[Optional["GetPersonPersonHomeLocation"]]] = Field(
        alias="homeLocation"
    )
    work_location: Optional[List[Optional["GetPersonPersonWorkLocation"]]] = Field(
        alias="workLocation"
    )


class GetPersonPersonOwner(BaseModel):
    id: str


class GetPersonPersonFeeds(BaseModel):
    id: str
    name: str


class GetPersonPersonLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class GetPersonPersonWorkflow(BaseModel):
    id: str
    name: str


class GetPersonPersonLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class GetPersonPersonH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class GetPersonPersonAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class GetPersonPersonWorksFor(BaseModel):
    id: str
    name: str


class GetPersonPersonAffiliation(BaseModel):
    id: str
    name: str


class GetPersonPersonMemberOf(BaseModel):
    id: str
    name: str


class GetPersonPersonAlumniOf(BaseModel):
    id: str
    name: str


class GetPersonPersonBirthPlace(BaseModel):
    id: str
    name: str


class GetPersonPersonDeathPlace(BaseModel):
    id: str
    name: str


class GetPersonPersonHomeLocation(BaseModel):
    id: str
    name: str


class GetPersonPersonWorkLocation(BaseModel):
    id: str
    name: str


GetPerson.model_rebuild()
GetPersonPerson.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class ExtractContents(BaseModel):
    extract_contents: Optional[List[Optional["ExtractContentsExtractContents"]]] = (
        Field(alias="extractContents")
    )


class ExtractContentsExtractContents(BaseModel):
    specification: Optional["ExtractContentsExtractContentsSpecification"]
    content: Optional["ExtractContentsExtractContentsContent"]
    name: str
    value: str
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    error: Optional[str]


class ExtractContentsExtractContentsSpecification(BaseModel):
    id: str


class ExtractContentsExtractContentsContent(BaseModel):
    id: str


ExtractContents.model_rebuild()
ExtractContentsExtractContents.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalProcedure(BaseModel):
    create_medical_procedure: Optional[
        "CreateMedicalProcedureCreateMedicalProcedure"
    ] = Field(alias="createMedicalProcedure")


class CreateMedicalProcedureCreateMedicalProcedure(BaseModel):
    id: str
    name: str


CreateMedicalProcedure.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteInvestmentFund(BaseModel):
    delete_investment_fund: Optional["DeleteInvestmentFundDeleteInvestmentFund"] = (
        Field(alias="deleteInvestmentFund")
    )


class DeleteInvestmentFundDeleteInvestmentFund(BaseModel):
    id: str
    state: EntityState


DeleteInvestmentFund.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class IsFeedDone(BaseModel):
    is_feed_done: Optional["IsFeedDoneIsFeedDone"] = Field(alias="isFeedDone")


class IsFeedDoneIsFeedDone(BaseModel):
    result: Optional[bool]


IsFeedDone.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateOrganization(BaseModel):
    create_organization: Optional["CreateOrganizationCreateOrganization"] = Field(
        alias="createOrganization"
    )


class CreateOrganizationCreateOrganization(BaseModel):
    id: str
    name: str


CreateOrganization.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class EnrichProducts(BaseModel):
    enrich_products: Optional[List[Optional["EnrichProductsEnrichProducts"]]] = Field(
        alias="enrichProducts"
    )


class EnrichProductsEnrichProducts(BaseModel):
    id: str
    name: str


EnrichProducts.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class CreateCollection(BaseModel):
    create_collection: Optional["CreateCollectionCreateCollection"] = Field(
        alias="createCollection"
    )


class CreateCollectionCreateCollection(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]


CreateCollection.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePlace(BaseModel):
    delete_place: Optional["DeletePlaceDeletePlace"] = Field(alias="deletePlace")


class DeletePlaceDeletePlace(BaseModel):
    id: str
    state: EntityState


DeletePlace.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateInvestmentFund(BaseModel):
    update_investment_fund: Optional["UpdateInvestmentFundUpdateInvestmentFund"] = (
        Field(alias="updateInvestmentFund")
    )


class UpdateInvestmentFundUpdateInvestmentFund(BaseModel):
    id: str
    name: str


UpdateInvestmentFund.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ObservableTypes


class ResolveEntities(BaseModel):
    resolve_entities: Optional["ResolveEntitiesResolveEntities"] = Field(
        alias="resolveEntities"
    )


class ResolveEntitiesResolveEntities(BaseModel):
    type: ObservableTypes
    primary: Optional["ResolveEntitiesResolveEntitiesPrimary"]
    resolved: Optional[List["ResolveEntitiesResolveEntitiesResolved"]]
    relevance: float
    reasoning: str
    primary_cluster: Optional["ResolveEntitiesResolveEntitiesPrimaryCluster"] = Field(
        alias="primaryCluster"
    )
    outlier_clusters: Optional[
        List["ResolveEntitiesResolveEntitiesOutlierClusters"]
    ] = Field(alias="outlierClusters")


class ResolveEntitiesResolveEntitiesPrimary(BaseModel):
    id: str


class ResolveEntitiesResolveEntitiesResolved(BaseModel):
    id: str


class ResolveEntitiesResolveEntitiesPrimaryCluster(BaseModel):
    entities: List["ResolveEntitiesResolveEntitiesPrimaryClusterEntities"]
    similarity: Optional[float]


class ResolveEntitiesResolveEntitiesPrimaryClusterEntities(BaseModel):
    id: str
    name: Optional[str]


class ResolveEntitiesResolveEntitiesOutlierClusters(BaseModel):
    entities: List["ResolveEntitiesResolveEntitiesOutlierClustersEntities"]
    similarity: Optional[float]


class ResolveEntitiesResolveEntitiesOutlierClustersEntities(BaseModel):
    id: str
    name: Optional[str]


ResolveEntities.model_rebuild()
ResolveEntitiesResolveEntities.model_rebuild()
ResolveEntitiesResolveEntitiesPrimaryCluster.model_rebuild()
ResolveEntitiesResolveEntitiesOutlierClusters.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountInvestmentFunds(BaseModel):
    count_investment_funds: Optional["CountInvestmentFundsCountInvestmentFunds"] = (
        Field(alias="countInvestmentFunds")
    )


class CountInvestmentFundsCountInvestmentFunds(BaseModel):
    count: Optional[Any]


CountInvestmentFunds.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    FilterMode,
    ObservableTypes,
    ViewTypes,
)


class UpsertView(BaseModel):
    upsert_view: Optional["UpsertViewUpsertView"] = Field(alias="upsertView")


class UpsertViewUpsertView(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ViewTypes]
    filter: Optional["UpsertViewUpsertViewFilter"]
    augmented_filter: Optional["UpsertViewUpsertViewAugmentedFilter"] = Field(
        alias="augmentedFilter"
    )


class UpsertViewUpsertViewFilter(BaseModel):
    date_range: Optional["UpsertViewUpsertViewFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional["UpsertViewUpsertViewFilterCreationDateRange"] = (
        Field(alias="creationDateRange")
    )
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[List[str]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["UpsertViewUpsertViewFilterFileSizeRange"] = Field(
        alias="fileSizeRange"
    )
    similar_contents: Optional[List["UpsertViewUpsertViewFilterSimilarContents"]] = (
        Field(alias="similarContents")
    )
    contents: Optional[List["UpsertViewUpsertViewFilterContents"]]
    feeds: Optional[List["UpsertViewUpsertViewFilterFeeds"]]
    workflows: Optional[List["UpsertViewUpsertViewFilterWorkflows"]]
    collections: Optional[List["UpsertViewUpsertViewFilterCollections"]]
    users: Optional[List["UpsertViewUpsertViewFilterUsers"]]
    observations: Optional[List["UpsertViewUpsertViewFilterObservations"]]
    or_: Optional[List["UpsertViewUpsertViewFilterOr"]] = Field(alias="or")
    and_: Optional[List["UpsertViewUpsertViewFilterAnd"]] = Field(alias="and")
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")
    collection_mode: Optional[FilterMode] = Field(alias="collectionMode")
    observation_mode: Optional[FilterMode] = Field(alias="observationMode")


class UpsertViewUpsertViewFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpsertViewUpsertViewFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpsertViewUpsertViewFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpsertViewUpsertViewFilterSimilarContents(BaseModel):
    id: str


class UpsertViewUpsertViewFilterContents(BaseModel):
    id: str


class UpsertViewUpsertViewFilterFeeds(BaseModel):
    id: str


class UpsertViewUpsertViewFilterWorkflows(BaseModel):
    id: str


class UpsertViewUpsertViewFilterCollections(BaseModel):
    id: str


class UpsertViewUpsertViewFilterUsers(BaseModel):
    id: str


class UpsertViewUpsertViewFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "UpsertViewUpsertViewFilterObservationsObservable"
    states: Optional[List[EntityState]]


class UpsertViewUpsertViewFilterObservationsObservable(BaseModel):
    id: str


class UpsertViewUpsertViewFilterOr(BaseModel):
    feeds: Optional[List["UpsertViewUpsertViewFilterOrFeeds"]]
    workflows: Optional[List["UpsertViewUpsertViewFilterOrWorkflows"]]
    collections: Optional[List["UpsertViewUpsertViewFilterOrCollections"]]
    users: Optional[List["UpsertViewUpsertViewFilterOrUsers"]]
    observations: Optional[List["UpsertViewUpsertViewFilterOrObservations"]]


class UpsertViewUpsertViewFilterOrFeeds(BaseModel):
    id: str


class UpsertViewUpsertViewFilterOrWorkflows(BaseModel):
    id: str


class UpsertViewUpsertViewFilterOrCollections(BaseModel):
    id: str


class UpsertViewUpsertViewFilterOrUsers(BaseModel):
    id: str


class UpsertViewUpsertViewFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "UpsertViewUpsertViewFilterOrObservationsObservable"
    states: Optional[List[EntityState]]


class UpsertViewUpsertViewFilterOrObservationsObservable(BaseModel):
    id: str


class UpsertViewUpsertViewFilterAnd(BaseModel):
    feeds: Optional[List["UpsertViewUpsertViewFilterAndFeeds"]]
    workflows: Optional[List["UpsertViewUpsertViewFilterAndWorkflows"]]
    collections: Optional[List["UpsertViewUpsertViewFilterAndCollections"]]
    users: Optional[List["UpsertViewUpsertViewFilterAndUsers"]]
    observations: Optional[List["UpsertViewUpsertViewFilterAndObservations"]]


class UpsertViewUpsertViewFilterAndFeeds(BaseModel):
    id: str


class UpsertViewUpsertViewFilterAndWorkflows(BaseModel):
    id: str


class UpsertViewUpsertViewFilterAndCollections(BaseModel):
    id: str


class UpsertViewUpsertViewFilterAndUsers(BaseModel):
    id: str


class UpsertViewUpsertViewFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "UpsertViewUpsertViewFilterAndObservationsObservable"
    states: Optional[List[EntityState]]


class UpsertViewUpsertViewFilterAndObservationsObservable(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilter(BaseModel):
    date_range: Optional["UpsertViewUpsertViewAugmentedFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional[
        "UpsertViewUpsertViewAugmentedFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[List[str]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["UpsertViewUpsertViewAugmentedFilterFileSizeRange"] = (
        Field(alias="fileSizeRange")
    )
    similar_contents: Optional[
        List["UpsertViewUpsertViewAugmentedFilterSimilarContents"]
    ] = Field(alias="similarContents")
    contents: Optional[List["UpsertViewUpsertViewAugmentedFilterContents"]]
    feeds: Optional[List["UpsertViewUpsertViewAugmentedFilterFeeds"]]
    workflows: Optional[List["UpsertViewUpsertViewAugmentedFilterWorkflows"]]
    collections: Optional[List["UpsertViewUpsertViewAugmentedFilterCollections"]]
    users: Optional[List["UpsertViewUpsertViewAugmentedFilterUsers"]]
    observations: Optional[List["UpsertViewUpsertViewAugmentedFilterObservations"]]
    or_: Optional[List["UpsertViewUpsertViewAugmentedFilterOr"]] = Field(alias="or")
    and_: Optional[List["UpsertViewUpsertViewAugmentedFilterAnd"]] = Field(alias="and")
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")
    collection_mode: Optional[FilterMode] = Field(alias="collectionMode")
    observation_mode: Optional[FilterMode] = Field(alias="observationMode")


class UpsertViewUpsertViewAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpsertViewUpsertViewAugmentedFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpsertViewUpsertViewAugmentedFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpsertViewUpsertViewAugmentedFilterSimilarContents(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterContents(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterFeeds(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterWorkflows(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterCollections(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterUsers(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "UpsertViewUpsertViewAugmentedFilterObservationsObservable"
    states: Optional[List[EntityState]]


class UpsertViewUpsertViewAugmentedFilterObservationsObservable(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterOr(BaseModel):
    feeds: Optional[List["UpsertViewUpsertViewAugmentedFilterOrFeeds"]]
    workflows: Optional[List["UpsertViewUpsertViewAugmentedFilterOrWorkflows"]]
    collections: Optional[List["UpsertViewUpsertViewAugmentedFilterOrCollections"]]
    users: Optional[List["UpsertViewUpsertViewAugmentedFilterOrUsers"]]
    observations: Optional[List["UpsertViewUpsertViewAugmentedFilterOrObservations"]]


class UpsertViewUpsertViewAugmentedFilterOrFeeds(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterOrWorkflows(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterOrCollections(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterOrUsers(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "UpsertViewUpsertViewAugmentedFilterOrObservationsObservable"
    states: Optional[List[EntityState]]


class UpsertViewUpsertViewAugmentedFilterOrObservationsObservable(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterAnd(BaseModel):
    feeds: Optional[List["UpsertViewUpsertViewAugmentedFilterAndFeeds"]]
    workflows: Optional[List["UpsertViewUpsertViewAugmentedFilterAndWorkflows"]]
    collections: Optional[List["UpsertViewUpsertViewAugmentedFilterAndCollections"]]
    users: Optional[List["UpsertViewUpsertViewAugmentedFilterAndUsers"]]
    observations: Optional[List["UpsertViewUpsertViewAugmentedFilterAndObservations"]]


class UpsertViewUpsertViewAugmentedFilterAndFeeds(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterAndWorkflows(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterAndCollections(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterAndUsers(BaseModel):
    id: str


class UpsertViewUpsertViewAugmentedFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "UpsertViewUpsertViewAugmentedFilterAndObservationsObservable"
    states: Optional[List[EntityState]]


class UpsertViewUpsertViewAugmentedFilterAndObservationsObservable(BaseModel):
    id: str


UpsertView.model_rebuild()
UpsertViewUpsertView.model_rebuild()
UpsertViewUpsertViewFilter.model_rebuild()
UpsertViewUpsertViewFilterObservations.model_rebuild()
UpsertViewUpsertViewFilterOr.model_rebuild()
UpsertViewUpsertViewFilterOrObservations.model_rebuild()
UpsertViewUpsertViewFilterAnd.model_rebuild()
UpsertViewUpsertViewFilterAndObservations.model_rebuild()
UpsertViewUpsertViewAugmentedFilter.model_rebuild()
UpsertViewUpsertViewAugmentedFilterObservations.model_rebuild()
UpsertViewUpsertViewAugmentedFilterOr.model_rebuild()
UpsertViewUpsertViewAugmentedFilterOrObservations.model_rebuild()
UpsertViewUpsertViewAugmentedFilterAnd.model_rebuild()
UpsertViewUpsertViewAugmentedFilterAndObservations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateInvestment(BaseModel):
    update_investment: Optional["UpdateInvestmentUpdateInvestment"] = Field(
        alias="updateInvestment"
    )


class UpdateInvestmentUpdateInvestment(BaseModel):
    id: str
    name: str


UpdateInvestment.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllInvestmentFunds(BaseModel):
    delete_all_investment_funds: Optional[
        List[Optional["DeleteAllInvestmentFundsDeleteAllInvestmentFunds"]]
    ] = Field(alias="deleteAllInvestmentFunds")


class DeleteAllInvestmentFundsDeleteAllInvestmentFunds(BaseModel):
    id: str
    state: EntityState


DeleteAllInvestmentFunds.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateInvestment(BaseModel):
    create_investment: Optional["CreateInvestmentCreateInvestment"] = Field(
        alias="createInvestment"
    )


class CreateInvestmentCreateInvestment(BaseModel):
    id: str
    name: str


CreateInvestment.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountWorkflows(BaseModel):
    count_workflows: Optional["CountWorkflowsCountWorkflows"] = Field(
        alias="countWorkflows"
    )


class CountWorkflowsCountWorkflows(BaseModel):
    count: Optional[Any]


CountWorkflows.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ArcadeProviders,
    AuthenticationServiceTypes,
    ConnectorTypes,
    EntityState,
    IntegrationServiceTypes,
    MCPServerTypes,
    OAuthProviders,
)


class QueryConnectors(BaseModel):
    connectors: Optional["QueryConnectorsConnectors"]


class QueryConnectorsConnectors(BaseModel):
    results: Optional[List["QueryConnectorsConnectorsResults"]]


class QueryConnectorsConnectorsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryConnectorsConnectorsResultsOwner"
    state: EntityState
    type: Optional[ConnectorTypes]
    authentication: Optional["QueryConnectorsConnectorsResultsAuthentication"]
    integration: Optional["QueryConnectorsConnectorsResultsIntegration"]


class QueryConnectorsConnectorsResultsOwner(BaseModel):
    id: str


class QueryConnectorsConnectorsResultsAuthentication(BaseModel):
    type: AuthenticationServiceTypes
    microsoft: Optional["QueryConnectorsConnectorsResultsAuthenticationMicrosoft"]
    google: Optional["QueryConnectorsConnectorsResultsAuthenticationGoogle"]
    oauth: Optional["QueryConnectorsConnectorsResultsAuthenticationOauth"]
    arcade: Optional["QueryConnectorsConnectorsResultsAuthenticationArcade"]


class QueryConnectorsConnectorsResultsAuthenticationMicrosoft(BaseModel):
    tenant_id: str = Field(alias="tenantId")
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class QueryConnectorsConnectorsResultsAuthenticationGoogle(BaseModel):
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class QueryConnectorsConnectorsResultsAuthenticationOauth(BaseModel):
    provider: OAuthProviders
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")
    refresh_token: str = Field(alias="refreshToken")
    metadata: Optional[str]


class QueryConnectorsConnectorsResultsAuthenticationArcade(BaseModel):
    authorization_id: str = Field(alias="authorizationId")
    provider: ArcadeProviders
    metadata: Optional[str]


class QueryConnectorsConnectorsResultsIntegration(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["QueryConnectorsConnectorsResultsIntegrationSlack"]
    email: Optional["QueryConnectorsConnectorsResultsIntegrationEmail"]
    twitter: Optional["QueryConnectorsConnectorsResultsIntegrationTwitter"]
    mcp: Optional["QueryConnectorsConnectorsResultsIntegrationMcp"]


class QueryConnectorsConnectorsResultsIntegrationSlack(BaseModel):
    token: str
    channel: str


class QueryConnectorsConnectorsResultsIntegrationEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class QueryConnectorsConnectorsResultsIntegrationTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


class QueryConnectorsConnectorsResultsIntegrationMcp(BaseModel):
    token: Optional[str]
    type: MCPServerTypes


QueryConnectors.model_rebuild()
QueryConnectorsConnectors.model_rebuild()
QueryConnectorsConnectorsResults.model_rebuild()
QueryConnectorsConnectorsResultsAuthentication.model_rebuild()
QueryConnectorsConnectorsResultsIntegration.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class EnableUser(BaseModel):
    enable_user: Optional["EnableUserEnableUser"] = Field(alias="enableUser")


class EnableUserEnableUser(BaseModel):
    id: str
    state: EntityState


EnableUser.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    ObservableTypes,
    OccurrenceTypes,
)


class ScreenshotPage(BaseModel):
    screenshot_page: Optional["ScreenshotPageScreenshotPage"] = Field(
        alias="screenshotPage"
    )


class ScreenshotPageScreenshotPage(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    uri: Optional[Any]
    identifier: Optional[str]
    collections: Optional[List[Optional["ScreenshotPageScreenshotPageCollections"]]]
    observations: Optional[List[Optional["ScreenshotPageScreenshotPageObservations"]]]


class ScreenshotPageScreenshotPageCollections(BaseModel):
    id: str
    name: str


class ScreenshotPageScreenshotPageObservations(BaseModel):
    id: str
    type: ObservableTypes
    observable: "ScreenshotPageScreenshotPageObservationsObservable"
    related: Optional["ScreenshotPageScreenshotPageObservationsRelated"]
    related_type: Optional[ObservableTypes] = Field(alias="relatedType")
    relation: Optional[str]
    occurrences: Optional[
        List[Optional["ScreenshotPageScreenshotPageObservationsOccurrences"]]
    ]
    state: EntityState


class ScreenshotPageScreenshotPageObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class ScreenshotPageScreenshotPageObservationsRelated(BaseModel):
    id: str
    name: Optional[str]


class ScreenshotPageScreenshotPageObservationsOccurrences(BaseModel):
    type: Optional[OccurrenceTypes]
    confidence: Optional[float]
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_index: Optional[int] = Field(alias="pageIndex")
    bounding_box: Optional[
        "ScreenshotPageScreenshotPageObservationsOccurrencesBoundingBox"
    ] = Field(alias="boundingBox")


class ScreenshotPageScreenshotPageObservationsOccurrencesBoundingBox(BaseModel):
    left: Optional[float]
    top: Optional[float]
    width: Optional[float]
    height: Optional[float]


ScreenshotPage.model_rebuild()
ScreenshotPageScreenshotPage.model_rebuild()
ScreenshotPageScreenshotPageObservations.model_rebuild()
ScreenshotPageScreenshotPageObservationsOccurrences.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteProduct(BaseModel):
    delete_product: Optional["DeleteProductDeleteProduct"] = Field(
        alias="deleteProduct"
    )


class DeleteProductDeleteProduct(BaseModel):
    id: str
    state: EntityState


DeleteProduct.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AttioAuthenticationTypes,
    BlobListingTypes,
    BoxAuthenticationTypes,
    CalendarListingTypes,
    DropboxAuthenticationTypes,
    EmailListingTypes,
    EntityState,
    FeedListingTypes,
    FeedServiceTypes,
    FeedSyncMode,
    FeedTypes,
    GitHubAuthenticationTypes,
    GitHubCommitAuthenticationTypes,
    GitHubIssueAuthenticationTypes,
    GitHubPullRequestAuthenticationTypes,
    GoogleCalendarAuthenticationTypes,
    GoogleContactsAuthenticationTypes,
    GoogleDriveAuthenticationTypes,
    GoogleEmailAuthenticationTypes,
    MicrosoftCalendarAuthenticationTypes,
    MicrosoftContactsAuthenticationTypes,
    MicrosoftEmailAuthenticationTypes,
    MicrosoftTeamsAuthenticationTypes,
    NotionTypes,
    OneDriveAuthenticationTypes,
    ParallelGenerators,
    ParallelProcessors,
    SearchServiceTypes,
    SharePointAuthenticationTypes,
    SiteTypes,
    TimedPolicyRecurrenceTypes,
    TrelloTypes,
    TwitterListingTypes,
    YouTubeTypes,
)


class GetFeed(BaseModel):
    feed: Optional["GetFeedFeed"]


class GetFeedFeed(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetFeedFeedOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: FeedTypes
    sync_mode: Optional[FeedSyncMode] = Field(alias="syncMode")
    site: Optional["GetFeedFeedSite"]
    email: Optional["GetFeedFeedEmail"]
    issue: Optional["GetFeedFeedIssue"]
    commit: Optional["GetFeedFeedCommit"]
    pull_request: Optional["GetFeedFeedPullRequest"] = Field(alias="pullRequest")
    crm: Optional["GetFeedFeedCrm"]
    calendar: Optional["GetFeedFeedCalendar"]
    rss: Optional["GetFeedFeedRss"]
    web: Optional["GetFeedFeedWeb"]
    search: Optional["GetFeedFeedSearch"]
    reddit: Optional["GetFeedFeedReddit"]
    notion: Optional["GetFeedFeedNotion"]
    intercom: Optional["GetFeedFeedIntercom"]
    zendesk: Optional["GetFeedFeedZendesk"]
    youtube: Optional["GetFeedFeedYoutube"]
    twitter: Optional["GetFeedFeedTwitter"]
    slack: Optional["GetFeedFeedSlack"]
    microsoft_teams: Optional["GetFeedFeedMicrosoftTeams"] = Field(
        alias="microsoftTeams"
    )
    discord: Optional["GetFeedFeedDiscord"]
    attio: Optional["GetFeedFeedAttio"]
    research: Optional["GetFeedFeedResearch"]
    entity: Optional["GetFeedFeedEntity"]
    error: Optional[str]
    last_post_date: Optional[Any] = Field(alias="lastPostDate")
    last_read_date: Optional[Any] = Field(alias="lastReadDate")
    read_count: Optional[int] = Field(alias="readCount")
    workflow: Optional["GetFeedFeedWorkflow"]
    schedule_policy: Optional["GetFeedFeedSchedulePolicy"] = Field(
        alias="schedulePolicy"
    )


class GetFeedFeedOwner(BaseModel):
    id: str


class GetFeedFeedSite(BaseModel):
    site_type: SiteTypes = Field(alias="siteType")
    type: FeedServiceTypes
    is_recursive: Optional[bool] = Field(alias="isRecursive")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")
    s_3: Optional["GetFeedFeedSiteS3"] = Field(alias="s3")
    azure_blob: Optional["GetFeedFeedSiteAzureBlob"] = Field(alias="azureBlob")
    azure_file: Optional["GetFeedFeedSiteAzureFile"] = Field(alias="azureFile")
    google: Optional["GetFeedFeedSiteGoogle"]
    share_point: Optional["GetFeedFeedSiteSharePoint"] = Field(alias="sharePoint")
    one_drive: Optional["GetFeedFeedSiteOneDrive"] = Field(alias="oneDrive")
    google_drive: Optional["GetFeedFeedSiteGoogleDrive"] = Field(alias="googleDrive")
    dropbox: Optional["GetFeedFeedSiteDropbox"]
    box: Optional["GetFeedFeedSiteBox"]
    github: Optional["GetFeedFeedSiteGithub"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedSiteS3(BaseModel):
    access_key: Optional[str] = Field(alias="accessKey")
    secret_access_key: Optional[str] = Field(alias="secretAccessKey")
    bucket_name: Optional[str] = Field(alias="bucketName")
    prefix: Optional[str]
    region: Optional[str]


class GetFeedFeedSiteAzureBlob(BaseModel):
    storage_access_key: Optional[str] = Field(alias="storageAccessKey")
    account_name: Optional[str] = Field(alias="accountName")
    container_name: Optional[str] = Field(alias="containerName")
    prefix: Optional[str]
    list_type: Optional[BlobListingTypes] = Field(alias="listType")


class GetFeedFeedSiteAzureFile(BaseModel):
    storage_access_key: Optional[str] = Field(alias="storageAccessKey")
    account_name: Optional[str] = Field(alias="accountName")
    share_name: Optional[str] = Field(alias="shareName")
    prefix: Optional[str]


class GetFeedFeedSiteGoogle(BaseModel):
    credentials: Optional[str]
    container_name: Optional[str] = Field(alias="containerName")
    prefix: Optional[str]


class GetFeedFeedSiteSharePoint(BaseModel):
    authentication_type: Optional[SharePointAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    account_name: str = Field(alias="accountName")
    library_id: str = Field(alias="libraryId")
    folder_id: Optional[str] = Field(alias="folderId")
    tenant_id: Optional[str] = Field(alias="tenantId")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedSiteSharePointConnector"]


class GetFeedFeedSiteSharePointConnector(BaseModel):
    id: str


class GetFeedFeedSiteOneDrive(BaseModel):
    authentication_type: Optional[OneDriveAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    folder_id: Optional[str] = Field(alias="folderId")
    files: Optional[List[Optional[str]]]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedSiteOneDriveConnector"]


class GetFeedFeedSiteOneDriveConnector(BaseModel):
    id: str


class GetFeedFeedSiteGoogleDrive(BaseModel):
    authentication_type: Optional[GoogleDriveAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    folder_id: Optional[str] = Field(alias="folderId")
    files: Optional[List[Optional[str]]]
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    service_account_json: Optional[str] = Field(alias="serviceAccountJson")
    connector: Optional["GetFeedFeedSiteGoogleDriveConnector"]


class GetFeedFeedSiteGoogleDriveConnector(BaseModel):
    id: str


class GetFeedFeedSiteDropbox(BaseModel):
    authentication_type: Optional[DropboxAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    path: Optional[str]
    app_key: Optional[str] = Field(alias="appKey")
    app_secret: Optional[str] = Field(alias="appSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")


class GetFeedFeedSiteBox(BaseModel):
    authentication_type: Optional[BoxAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    folder_id: Optional[str] = Field(alias="folderId")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    redirect_uri: Optional[str] = Field(alias="redirectUri")


class GetFeedFeedSiteGithub(BaseModel):
    authentication_type: Optional[GitHubAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["GetFeedFeedSiteGithubConnector"]


class GetFeedFeedSiteGithubConnector(BaseModel):
    id: str


class GetFeedFeedEmail(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    google: Optional["GetFeedFeedEmailGoogle"]
    microsoft: Optional["GetFeedFeedEmailMicrosoft"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedEmailGoogle(BaseModel):
    type: Optional[EmailListingTypes]
    filter: Optional[str]
    include_spam: Optional[bool] = Field(alias="includeSpam")
    exclude_sent_items: Optional[bool] = Field(alias="excludeSentItems")
    include_deleted_items: Optional[bool] = Field(alias="includeDeletedItems")
    inbox_only: Optional[bool] = Field(alias="inboxOnly")
    authentication_type: Optional[GoogleEmailAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["GetFeedFeedEmailGoogleConnector"]


class GetFeedFeedEmailGoogleConnector(BaseModel):
    id: str


class GetFeedFeedEmailMicrosoft(BaseModel):
    type: Optional[EmailListingTypes]
    filter: Optional[str]
    include_spam: Optional[bool] = Field(alias="includeSpam")
    exclude_sent_items: Optional[bool] = Field(alias="excludeSentItems")
    include_deleted_items: Optional[bool] = Field(alias="includeDeletedItems")
    inbox_only: Optional[bool] = Field(alias="inboxOnly")
    authentication_type: Optional[MicrosoftEmailAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["GetFeedFeedEmailMicrosoftConnector"]


class GetFeedFeedEmailMicrosoftConnector(BaseModel):
    id: str


class GetFeedFeedIssue(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    jira: Optional["GetFeedFeedIssueJira"]
    linear: Optional["GetFeedFeedIssueLinear"]
    github: Optional["GetFeedFeedIssueGithub"]
    intercom: Optional["GetFeedFeedIssueIntercom"]
    zendesk: Optional["GetFeedFeedIssueZendesk"]
    trello: Optional["GetFeedFeedIssueTrello"]
    attio: Optional["GetFeedFeedIssueAttio"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedIssueJira(BaseModel):
    uri: Any
    project: str
    email: str
    token: str
    offset: Optional[Any]


class GetFeedFeedIssueLinear(BaseModel):
    key: str
    project: str


class GetFeedFeedIssueGithub(BaseModel):
    authentication_type: Optional[GitHubIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["GetFeedFeedIssueGithubConnector"]


class GetFeedFeedIssueGithubConnector(BaseModel):
    id: str


class GetFeedFeedIssueIntercom(BaseModel):
    access_token: str = Field(alias="accessToken")


class GetFeedFeedIssueZendesk(BaseModel):
    subdomain: str
    access_token: str = Field(alias="accessToken")


class GetFeedFeedIssueTrello(BaseModel):
    key: str
    token: str
    identifiers: List[str]
    type: TrelloTypes


class GetFeedFeedIssueAttio(BaseModel):
    api_key: str = Field(alias="apiKey")


class GetFeedFeedCommit(BaseModel):
    type: FeedServiceTypes
    github: Optional["GetFeedFeedCommitGithub"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedCommitGithub(BaseModel):
    authentication_type: Optional[GitHubCommitAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["GetFeedFeedCommitGithubConnector"]


class GetFeedFeedCommitGithubConnector(BaseModel):
    id: str


class GetFeedFeedPullRequest(BaseModel):
    type: FeedServiceTypes
    github: Optional["GetFeedFeedPullRequestGithub"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedPullRequestGithub(BaseModel):
    authentication_type: Optional[GitHubPullRequestAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["GetFeedFeedPullRequestGithubConnector"]


class GetFeedFeedPullRequestGithubConnector(BaseModel):
    id: str


class GetFeedFeedCrm(BaseModel):
    type: FeedServiceTypes
    attio: Optional["GetFeedFeedCrmAttio"]
    google_contacts: Optional["GetFeedFeedCrmGoogleContacts"] = Field(
        alias="googleContacts"
    )
    microsoft_contacts: Optional["GetFeedFeedCrmMicrosoftContacts"] = Field(
        alias="microsoftContacts"
    )
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedCrmAttio(BaseModel):
    authentication_type: Optional[AttioAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")


class GetFeedFeedCrmGoogleContacts(BaseModel):
    authentication_type: Optional[GoogleContactsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedCrmGoogleContactsConnector"]


class GetFeedFeedCrmGoogleContactsConnector(BaseModel):
    id: str


class GetFeedFeedCrmMicrosoftContacts(BaseModel):
    authentication_type: Optional[MicrosoftContactsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    tenant_id: Optional[str] = Field(alias="tenantId")
    connector: Optional["GetFeedFeedCrmMicrosoftContactsConnector"]


class GetFeedFeedCrmMicrosoftContactsConnector(BaseModel):
    id: str


class GetFeedFeedCalendar(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    enable_meeting_recording: Optional[bool] = Field(alias="enableMeetingRecording")
    meeting_bot_name: Optional[str] = Field(alias="meetingBotName")
    google: Optional["GetFeedFeedCalendarGoogle"]
    microsoft: Optional["GetFeedFeedCalendarMicrosoft"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedCalendarGoogle(BaseModel):
    type: Optional[CalendarListingTypes]
    calendar_id: Optional[str] = Field(alias="calendarId")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[GoogleCalendarAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["GetFeedFeedCalendarGoogleConnector"]


class GetFeedFeedCalendarGoogleConnector(BaseModel):
    id: str


class GetFeedFeedCalendarMicrosoft(BaseModel):
    type: Optional[CalendarListingTypes]
    calendar_id: Optional[str] = Field(alias="calendarId")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[MicrosoftCalendarAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["GetFeedFeedCalendarMicrosoftConnector"]


class GetFeedFeedCalendarMicrosoftConnector(BaseModel):
    id: str


class GetFeedFeedRss(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    uri: Any


class GetFeedFeedWeb(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    uri: Any
    include_files: Optional[bool] = Field(alias="includeFiles")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")


class GetFeedFeedSearch(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[SearchServiceTypes]
    text: str


class GetFeedFeedReddit(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    subreddit_name: str = Field(alias="subredditName")


class GetFeedFeedNotion(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    token: str
    identifiers: List[str]
    type: NotionTypes


class GetFeedFeedIntercom(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    access_token: str = Field(alias="accessToken")


class GetFeedFeedZendesk(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    subdomain: str
    access_token: str = Field(alias="accessToken")


class GetFeedFeedYoutube(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: YouTubeTypes
    video_name: Optional[str] = Field(alias="videoName")
    video_identifiers: Optional[List[str]] = Field(alias="videoIdentifiers")
    channel_identifier: Optional[str] = Field(alias="channelIdentifier")
    playlist_identifier: Optional[str] = Field(alias="playlistIdentifier")


class GetFeedFeedTwitter(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    token: str
    type: Optional[TwitterListingTypes]
    user_name: Optional[str] = Field(alias="userName")
    query: Optional[str]
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedSlack(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    token: str
    channel: str
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedMicrosoftTeams(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    authentication_type: Optional[MicrosoftTeamsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedMicrosoftTeamsConnector"]
    team_id: str = Field(alias="teamId")
    channel_id: str = Field(alias="channelId")


class GetFeedFeedMicrosoftTeamsConnector(BaseModel):
    id: str


class GetFeedFeedDiscord(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    token: str
    channel: str
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedAttio(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    api_key: str = Field(alias="apiKey")


class GetFeedFeedResearch(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedServiceTypes]
    query: str
    parallel: Optional["GetFeedFeedResearchParallel"]


class GetFeedFeedResearchParallel(BaseModel):
    processor: Optional[ParallelProcessors]


class GetFeedFeedEntity(BaseModel):
    type: FeedServiceTypes
    query: str
    read_limit: Optional[int] = Field(alias="readLimit")
    parallel: Optional["GetFeedFeedEntityParallel"]


class GetFeedFeedEntityParallel(BaseModel):
    generator: Optional[ParallelGenerators]


class GetFeedFeedWorkflow(BaseModel):
    id: str
    name: str


class GetFeedFeedSchedulePolicy(BaseModel):
    recurrence_type: Optional[TimedPolicyRecurrenceTypes] = Field(
        alias="recurrenceType"
    )
    repeat_interval: Optional[Any] = Field(alias="repeatInterval")


GetFeed.model_rebuild()
GetFeedFeed.model_rebuild()
GetFeedFeedSite.model_rebuild()
GetFeedFeedSiteSharePoint.model_rebuild()
GetFeedFeedSiteOneDrive.model_rebuild()
GetFeedFeedSiteGoogleDrive.model_rebuild()
GetFeedFeedSiteGithub.model_rebuild()
GetFeedFeedEmail.model_rebuild()
GetFeedFeedEmailGoogle.model_rebuild()
GetFeedFeedEmailMicrosoft.model_rebuild()
GetFeedFeedIssue.model_rebuild()
GetFeedFeedIssueGithub.model_rebuild()
GetFeedFeedCommit.model_rebuild()
GetFeedFeedCommitGithub.model_rebuild()
GetFeedFeedPullRequest.model_rebuild()
GetFeedFeedPullRequestGithub.model_rebuild()
GetFeedFeedCrm.model_rebuild()
GetFeedFeedCrmGoogleContacts.model_rebuild()
GetFeedFeedCrmMicrosoftContacts.model_rebuild()
GetFeedFeedCalendar.model_rebuild()
GetFeedFeedCalendarGoogle.model_rebuild()
GetFeedFeedCalendarMicrosoft.model_rebuild()
GetFeedFeedMicrosoftTeams.model_rebuild()
GetFeedFeedResearch.model_rebuild()
GetFeedFeedEntity.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryInvestmentsClusters(BaseModel):
    investments: Optional["QueryInvestmentsClustersInvestments"]


class QueryInvestmentsClustersInvestments(BaseModel):
    results: Optional[List[Optional["QueryInvestmentsClustersInvestmentsResults"]]]
    clusters: Optional["QueryInvestmentsClustersInvestmentsClusters"]


class QueryInvestmentsClustersInvestmentsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryInvestmentsClustersInvestmentsResultsOwner"
    state: EntityState
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[List[Optional["QueryInvestmentsClustersInvestmentsResultsFeeds"]]]
    links: Optional[List[Optional["QueryInvestmentsClustersInvestmentsResultsLinks"]]]
    workflow: Optional["QueryInvestmentsClustersInvestmentsResultsWorkflow"]
    location: Optional["QueryInvestmentsClustersInvestmentsResultsLocation"]
    h_3: Optional["QueryInvestmentsClustersInvestmentsResultsH3"] = Field(alias="h3")
    amount: Optional[Any]
    amount_currency: Optional[str] = Field(alias="amountCurrency")
    status: Optional[str]
    stage: Optional[str]
    investment_date: Optional[Any] = Field(alias="investmentDate")
    round_size: Optional[Any] = Field(alias="roundSize")
    round_size_currency: Optional[str] = Field(alias="roundSizeCurrency")
    post_valuation: Optional[Any] = Field(alias="postValuation")
    post_valuation_currency: Optional[str] = Field(alias="postValuationCurrency")
    shares_owned: Optional[Any] = Field(alias="sharesOwned")
    vehicle: Optional[str]
    entry_price_per_share: Optional[Any] = Field(alias="entryPricePerShare")
    current_price_per_share: Optional[Any] = Field(alias="currentPricePerShare")
    discount_percent: Optional[Any] = Field(alias="discountPercent")
    pro_rata_rights: Optional[bool] = Field(alias="proRataRights")
    investor: Optional["QueryInvestmentsClustersInvestmentsResultsInvestor"]
    organization: Optional["QueryInvestmentsClustersInvestmentsResultsOrganization"]


class QueryInvestmentsClustersInvestmentsResultsOwner(BaseModel):
    id: str


class QueryInvestmentsClustersInvestmentsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryInvestmentsClustersInvestmentsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryInvestmentsClustersInvestmentsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryInvestmentsClustersInvestmentsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryInvestmentsClustersInvestmentsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryInvestmentsClustersInvestmentsResultsInvestor(BaseModel):
    id: str
    name: str


class QueryInvestmentsClustersInvestmentsResultsOrganization(BaseModel):
    id: str
    name: str


class QueryInvestmentsClustersInvestmentsClusters(BaseModel):
    clusters: Optional[List["QueryInvestmentsClustersInvestmentsClustersClusters"]]


class QueryInvestmentsClustersInvestmentsClustersClusters(BaseModel):
    entities: List["QueryInvestmentsClustersInvestmentsClustersClustersEntities"]
    similarity: Optional[float]


class QueryInvestmentsClustersInvestmentsClustersClustersEntities(BaseModel):
    id: str
    name: Optional[str]


QueryInvestmentsClusters.model_rebuild()
QueryInvestmentsClustersInvestments.model_rebuild()
QueryInvestmentsClustersInvestmentsResults.model_rebuild()
QueryInvestmentsClustersInvestmentsClusters.model_rebuild()
QueryInvestmentsClustersInvestmentsClustersClusters.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ConnectorTypes, EntityState


class UpdateConnector(BaseModel):
    update_connector: Optional["UpdateConnectorUpdateConnector"] = Field(
        alias="updateConnector"
    )


class UpdateConnectorUpdateConnector(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ConnectorTypes]


UpdateConnector.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryInvestments(BaseModel):
    investments: Optional["QueryInvestmentsInvestments"]


class QueryInvestmentsInvestments(BaseModel):
    results: Optional[List[Optional["QueryInvestmentsInvestmentsResults"]]]


class QueryInvestmentsInvestmentsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryInvestmentsInvestmentsResultsOwner"
    state: EntityState
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[List[Optional["QueryInvestmentsInvestmentsResultsFeeds"]]]
    links: Optional[List[Optional["QueryInvestmentsInvestmentsResultsLinks"]]]
    workflow: Optional["QueryInvestmentsInvestmentsResultsWorkflow"]
    location: Optional["QueryInvestmentsInvestmentsResultsLocation"]
    h_3: Optional["QueryInvestmentsInvestmentsResultsH3"] = Field(alias="h3")
    amount: Optional[Any]
    amount_currency: Optional[str] = Field(alias="amountCurrency")
    status: Optional[str]
    stage: Optional[str]
    investment_date: Optional[Any] = Field(alias="investmentDate")
    round_size: Optional[Any] = Field(alias="roundSize")
    round_size_currency: Optional[str] = Field(alias="roundSizeCurrency")
    post_valuation: Optional[Any] = Field(alias="postValuation")
    post_valuation_currency: Optional[str] = Field(alias="postValuationCurrency")
    shares_owned: Optional[Any] = Field(alias="sharesOwned")
    vehicle: Optional[str]
    entry_price_per_share: Optional[Any] = Field(alias="entryPricePerShare")
    current_price_per_share: Optional[Any] = Field(alias="currentPricePerShare")
    discount_percent: Optional[Any] = Field(alias="discountPercent")
    pro_rata_rights: Optional[bool] = Field(alias="proRataRights")


class QueryInvestmentsInvestmentsResultsOwner(BaseModel):
    id: str


class QueryInvestmentsInvestmentsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryInvestmentsInvestmentsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryInvestmentsInvestmentsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryInvestmentsInvestmentsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryInvestmentsInvestmentsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


QueryInvestments.model_rebuild()
QueryInvestmentsInvestments.model_rebuild()
QueryInvestmentsInvestmentsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalDrug(BaseModel):
    create_medical_drug: Optional["CreateMedicalDrugCreateMedicalDrug"] = Field(
        alias="createMedicalDrug"
    )


class CreateMedicalDrugCreateMedicalDrug(BaseModel):
    id: str
    name: str


CreateMedicalDrug.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ResearchContents(BaseModel):
    research_contents: Optional["ResearchContentsResearchContents"] = Field(
        alias="researchContents"
    )


class ResearchContentsResearchContents(BaseModel):
    result: Optional[str]


ResearchContents.model_rebuild()



# Generated by ariadne-codegen

import enum
import json
from typing import IO, Any, AsyncIterator, Dict, List, Optional, Tuple, TypeVar, cast
from uuid import uuid4

import httpx
from pydantic import BaseModel
from pydantic_core import to_jsonable_python

from .base_model import UNSET, Upload
from .exceptions import (
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQLClientInvalidMessageFormat,
    GraphQLClientInvalidResponseError,
)

try:
    from websockets import (  # type: ignore[import-not-found,unused-ignore]
        ClientConnection,
    )
    from websockets import (
        connect as ws_connect,
    )
    from websockets.typing import (  # type: ignore[import-not-found,unused-ignore]
        Data,
        Origin,
        Subprotocol,
    )
except ImportError:
    from contextlib import asynccontextmanager

    @asynccontextmanager  # type: ignore
    async def ws_connect(*args, **kwargs):
        raise NotImplementedError("Subscriptions require 'websockets' package.")
        yield

    ClientConnection = Any  # type: ignore[misc,assignment,unused-ignore]
    Data = Any  # type: ignore[misc,assignment,unused-ignore]
    Origin = Any  # type: ignore[misc,assignment,unused-ignore]

    def Subprotocol(*args, **kwargs):  # type: ignore # noqa: N802, N803
        raise NotImplementedError("Subscriptions require 'websockets' package.")


Self = TypeVar("Self", bound="AsyncBaseClient")

GRAPHQL_TRANSPORT_WS = "graphql-transport-ws"


class GraphQLTransportWSMessageType(str, enum.Enum):
    CONNECTION_INIT = "connection_init"
    CONNECTION_ACK = "connection_ack"
    PING = "ping"
    PONG = "pong"
    SUBSCRIBE = "subscribe"
    NEXT = "next"
    ERROR = "error"
    COMPLETE = "complete"


class AsyncBaseClient:
    def __init__(
        self,
        url: str = "",
        headers: Optional[Dict[str, str]] = None,
        http_client: Optional[httpx.AsyncClient] = None,
        ws_url: str = "",
        ws_headers: Optional[Dict[str, Any]] = None,
        ws_origin: Optional[str] = None,
        ws_connection_init_payload: Optional[Dict[str, Any]] = None,
    ) -> None:
        self.url = url
        self.headers = headers
        self.http_client = (
            http_client if http_client else httpx.AsyncClient(headers=headers)
        )

        self.ws_url = ws_url
        self.ws_headers = ws_headers or {}
        self.ws_origin = Origin(ws_origin) if ws_origin else None
        self.ws_connection_init_payload = ws_connection_init_payload

    async def __aenter__(self: Self) -> Self:
        return self

    async def __aexit__(
        self,
        exc_type: object,
        exc_val: object,
        exc_tb: object,
    ) -> None:
        await self.http_client.aclose()

    async def execute(
        self,
        query: str,
        operation_name: Optional[str] = None,
        variables: Optional[Dict[str, Any]] = None,
        **kwargs: Any,
    ) -> httpx.Response:
        processed_variables, files, files_map = self._process_variables(variables)

        if files and files_map:
            return await self._execute_multipart(
                query=query,
                operation_name=operation_name,
                variables=processed_variables,
                files=files,
                files_map=files_map,
                **kwargs,
            )

        return await self._execute_json(
            query=query,
            operation_name=operation_name,
            variables=processed_variables,
            **kwargs,
        )

    def get_data(self, response: httpx.Response) -> Dict[str, Any]:
        if not response.is_success:
            raise GraphQLClientHttpError(
                status_code=response.status_code, response=response
            )

        try:
            response_json = response.json()
        except ValueError as exc:
            raise GraphQLClientInvalidResponseError(response=response) from exc

        if (not isinstance(response_json, dict)) or (
            "data" not in response_json and "errors" not in response_json
        ):
            raise GraphQLClientInvalidResponseError(response=response)

        data = response_json.get("data")
        errors = response_json.get("errors")

        if errors:
            raise GraphQLClientGraphQLMultiError.from_errors_dicts(
                errors_dicts=errors, data=data
            )

        return cast(Dict[str, Any], data)

    async def execute_ws(
        self,
        query: str,
        operation_name: Optional[str] = None,
        variables: Optional[Dict[str, Any]] = None,
        **kwargs: Any,
    ) -> AsyncIterator[Dict[str, Any]]:
        headers = self.ws_headers.copy()
        headers.update(kwargs.get("extra_headers", {}))

        merged_kwargs: Dict[str, Any] = {"origin": self.ws_origin}
        merged_kwargs.update(kwargs)
        merged_kwargs["extra_headers"] = headers

        operation_id = str(uuid4())
        async with ws_connect(
            self.ws_url,
            subprotocols=[Subprotocol(GRAPHQL_TRANSPORT_WS)],
            **merged_kwargs,
        ) as websocket:
            await self._send_connection_init(websocket)
            # wait for connection_ack from server
            await self._handle_ws_message(
                await websocket.recv(),
                websocket,
                expected_type=GraphQLTransportWSMessageType.CONNECTION_ACK,
            )
            await self._send_subscribe(
                websocket,
                operation_id=operation_id,
                query=query,
                operation_name=operation_name,
                variables=variables,
            )

            async for message in websocket:
                data = await self._handle_ws_message(message, websocket)
                if data:
                    yield data

    def _process_variables(
        self, variables: Optional[Dict[str, Any]]
    ) -> Tuple[
        Dict[str, Any], Dict[str, Tuple[str, IO[bytes], str]], Dict[str, List[str]]
    ]:
        if not variables:
            return {}, {}, {}

        serializable_variables = self._convert_dict_to_json_serializable(variables)
        return self._get_files_from_variables(serializable_variables)

    def _convert_dict_to_json_serializable(
        self, dict_: Dict[str, Any]
    ) -> Dict[str, Any]:
        return {
            key: self._convert_value(value)
            for key, value in dict_.items()
            if value is not UNSET
        }

    def _convert_value(self, value: Any) -> Any:
        if isinstance(value, BaseModel):
            return value.model_dump(by_alias=True, exclude_unset=True)
        if isinstance(value, list):
            return [self._convert_value(item) for item in value]
        return value

    def _get_files_from_variables(
        self, variables: Dict[str, Any]
    ) -> Tuple[
        Dict[str, Any], Dict[str, Tuple[str, IO[bytes], str]], Dict[str, List[str]]
    ]:
        files_map: Dict[str, List[str]] = {}
        files_list: List[Upload] = []

        def separate_files(path: str, obj: Any) -> Any:
            if isinstance(obj, list):
                nulled_list = []
                for index, value in enumerate(obj):
                    value = separate_files(f"{path}.{index}", value)
                    nulled_list.append(value)
                return nulled_list

            if isinstance(obj, dict):
                nulled_dict = {}
                for key, value in obj.items():
                    value = separate_files(f"{path}.{key}", value)
                    nulled_dict[key] = value
                return nulled_dict

            if isinstance(obj, Upload):
                if obj in files_list:
                    file_index = files_list.index(obj)
                    files_map[str(file_index)].append(path)
                else:
                    file_index = len(files_list)
                    files_list.append(obj)
                    files_map[str(file_index)] = [path]
                return None

            return obj

        nulled_variables = separate_files("variables", variables)
        files: Dict[str, Tuple[str, IO[bytes], str]] = {
            str(i): (file_.filename, cast(IO[bytes], file_.content), file_.content_type)
            for i, file_ in enumerate(files_list)
        }
        return nulled_variables, files, files_map

    async def _execute_multipart(
        self,
        query: str,
        operation_name: Optional[str],
        variables: Dict[str, Any],
        files: Dict[str, Tuple[str, IO[bytes], str]],
        files_map: Dict[str, List[str]],
        **kwargs: Any,
    ) -> httpx.Response:
        data = {
            "operations": json.dumps(
                {
                    "query": query,
                    "operationName": operation_name,
                    "variables": variables,
                },
                default=to_jsonable_python,
            ),
            "map": json.dumps(files_map, default=to_jsonable_python),
        }

        return await self.http_client.post(
            url=self.url, data=data, files=files, **kwargs
        )

    async def _execute_json(
        self,
        query: str,
        operation_name: Optional[str],
        variables: Dict[str, Any],
        **kwargs: Any,
    ) -> httpx.Response:
        headers: Dict[str, str] = {"Content-Type": "application/json"}
        headers.update(kwargs.get("headers", {}))

        merged_kwargs: Dict[str, Any] = kwargs.copy()
        merged_kwargs["headers"] = headers

        return await self.http_client.post(
            url=self.url,
            content=json.dumps(
                {
                    "query": query,
                    "operationName": operation_name,
                    "variables": variables,
                },
                default=to_jsonable_python,
            ),
            **merged_kwargs,
        )

    async def _send_connection_init(self, websocket: ClientConnection) -> None:
        payload: Dict[str, Any] = {
            "type": GraphQLTransportWSMessageType.CONNECTION_INIT.value
        }
        if self.ws_connection_init_payload:
            payload["payload"] = self.ws_connection_init_payload
        await websocket.send(json.dumps(payload))

    async def _send_subscribe(
        self,
        websocket: ClientConnection,
        operation_id: str,
        query: str,
        operation_name: Optional[str] = None,
        variables: Optional[Dict[str, Any]] = None,
    ) -> None:
        payload: Dict[str, Any] = {
            "id": operation_id,
            "type": GraphQLTransportWSMessageType.SUBSCRIBE.value,
            "payload": {"query": query, "operationName": operation_name},
        }
        if variables:
            payload["payload"]["variables"] = self._convert_dict_to_json_serializable(
                variables
            )
        await websocket.send(json.dumps(payload))

    async def _handle_ws_message(
        self,
        message: Data,
        websocket: ClientConnection,
        expected_type: Optional[GraphQLTransportWSMessageType] = None,
    ) -> Optional[Dict[str, Any]]:
        try:
            message_dict = json.loads(message)
        except json.JSONDecodeError as exc:
            raise GraphQLClientInvalidMessageFormat(message=message) from exc

        type_ = message_dict.get("type")
        payload = message_dict.get("payload", {})

        if not type_ or type_ not in {t.value for t in GraphQLTransportWSMessageType}:
            raise GraphQLClientInvalidMessageFormat(message=message)

        if expected_type and expected_type != type_:
            raise GraphQLClientInvalidMessageFormat(
                f"Invalid message received. Expected: {expected_type.value}"
            )

        if type_ == GraphQLTransportWSMessageType.NEXT:
            if "data" not in payload:
                raise GraphQLClientInvalidMessageFormat(message=message)
            return cast(Dict[str, Any], payload["data"])

        if type_ == GraphQLTransportWSMessageType.COMPLETE:
            await websocket.close()
        elif type_ == GraphQLTransportWSMessageType.PING:
            await websocket.send(
                json.dumps({"type": GraphQLTransportWSMessageType.PONG.value})
            )
        elif type_ == GraphQLTransportWSMessageType.ERROR:
            raise GraphQLClientGraphQLMultiError.from_errors_dicts(
                errors_dicts=payload, data=message_dict
            )

        return None



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteInvestments(BaseModel):
    delete_investments: Optional[
        List[Optional["DeleteInvestmentsDeleteInvestments"]]
    ] = Field(alias="deleteInvestments")


class DeleteInvestmentsDeleteInvestments(BaseModel):
    id: str
    state: EntityState


DeleteInvestments.model_rebuild()
